@@ -42,7 +42,7 @@ class _WebSocketRoute:
             starlette.types.Receive: receive,
             starlette.types.Send: send,
         }
-        xpresso_scope: asgi_scope_extension.xpressoASGIExtension = scope["extensions"][
+        xpresso_scope: asgi_scope_extension.XpressoASGIExtension = scope["extensions"][
             "xpresso"
         ]
         async with xpresso_scope["container"].enter_scope("operation") as container:
@@ -79,7 +79,7 @@ class WebSocketRoute(starlette.routing.WebSocketRoute):
     ) -> None:
         self.dependant = container.solve(
             JoinedDependant(
-                Dependant(self.endpoint),
+                Dependant(self.endpoint, scope="operation"),
                 siblings=[*dependencies, *(self.dependencies or ())],
             )
         )
